@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-our $VERSION = 1.0005;
+our $VERSION = 1.0006;
 
 require Carp;
 
@@ -398,6 +398,10 @@ In alphabetical order
 
 David Leadbeater (dgl)
 
+Viacheslav Tykhanovskyi (vti)
+
+Yaroslav Korshak (yko)
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
